@@ -7,7 +7,10 @@ from pathlib import Path
 from typeddfs import TypedDfs
 
 
-def run():
+def run() -> None:
+    """
+    Runs an example usage of typeddfs.
+    """
 
     # Build me a Key-Value-Note class!
     KeyValue = TypedDfs.example()
@@ -18,13 +21,13 @@ def run():
 
     # And now, we can type a function to require a KeyValue,
     # and let it raise an `InvalidDfError` (here, a `MissingColumnError`):
-    def my_special_function(df: KeyValue) -> float:
-        return KeyValue(df)["value"].sum()
+    def my_special_function(dfx: KeyValue) -> float:
+        return KeyValue(dfx)["value"].sum()
 
     print(my_special_function(df))
 
 
 __all__ = ["example", "run"]
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     run()
